pub trait InstrumentResult<T> {
type Instrumented;
// Required method
fn in_current_span(self) -> Result<T, Self::Instrumented>;
}Available on crate feature
traced-error only.Expand description
Extension trait for instrumenting errors in Results with SpanTraces
Required Associated Types
Sourcetype Instrumented
type Instrumented
The type of the wrapped error after instrumentation
Required Methods
Sourcefn in_current_span(self) -> Result<T, Self::Instrumented>
fn in_current_span(self) -> Result<T, Self::Instrumented>
Instrument an Error by bundling it with a SpanTrace
Examples
use tracing_error::{TracedError, InstrumentResult};
fn do_thing() -> Result<(), TracedError<io::Error>> {
fallible_fn().in_current_span()
}